Class: SiriProxy::Plugin::Example
- Inherits:
-
SiriProxy::Plugin
- Object
- SiriProxy::Plugin
- SiriProxy::Plugin::Example
- Defined in:
- lib/siriproxy-example.rb
Overview
This is a “hello world” style plugin. It simply intercepts the phrase “test siri proxy” and responds with a message about the proxy being up and running (along with a couple other core features). This is good base code for other plugins.
Remember to add other plugins to the “config.yml” file if you create them!
Instance Method Summary collapse
-
#initialize(config) ⇒ Example
constructor
A new instance of Example.
Constructor Details
#initialize(config) ⇒ Example
Returns a new instance of Example.
14 15 16 |
# File 'lib/siriproxy-example.rb', line 14 def initialize(config) #if you have custom configuration options, process them here! end |